@@ -1,7 +1,8 @@
 """DNS Authenticator for Hetzner DNS."""
 import tldextract
-from certbot.plugins import dns_common, dns_common_lexicon
-from lexicon.providers import hetzner
+from certbot.plugins import dns_common
+from lexicon.client import Client
+from lexicon.config import ConfigResolver
 
 TTL = 60
 
@@ -20,9 +21,9 @@ class Authenticator(dns_common.DNSAuthenticator):
         self.credentials = None
 
     @classmethod
-    def add_parser_arguments(cls, add):  # pylint: disable=arguments-differ
+    def add_parser_arguments(cls, add, default_propagation_seconds = 60):
         super(Authenticator, cls).add_parser_arguments(
-            add, default_propagation_seconds=60
+            add, default_propagation_seconds=default_propagation_seconds
         )
         add("credentials", help="Hetzner credentials INI file.")
 
@@ -43,44 +44,32 @@ class Authenticator(dns_common.DNSAuthenticator):
 
     @staticmethod
     def _get_zone(domain):
-        zone_name = tldextract.extract(domain)
+        extract = tldextract.TLDExtract()
+        zone_name = extract(domain, include_psl_private_domains=True)
         return '.'.join([zone_name.domain, zone_name.suffix])
 
     def _perform(self, domain, validation_name, validation):
-        self._get_hetzner_client().add_txt_record(
-            self._get_zone(domain),
-            self._fqdn_format(validation_name),
-            validation
-        )
+        with self._get_hetzner_client(domain) as client:
+            client.create_record("TXT", self._fqdn_format(validation_name), validation)
 
     def _cleanup(self, domain, validation_name, validation):
-        self._get_hetzner_client().del_txt_record(
-            self._get_zone(domain),
-            self._fqdn_format(validation_name),
-            validation
-        )
+        with self._get_hetzner_client(domain) as client:
+            client.delete_record(None, "TXT", self._fqdn_format(validation_name), validation)
 
-    def _get_hetzner_client(self):
-        return _HetznerClient(self.credentials.conf("api_token"))
+    def _get_hetzner_client(self, domain):
+        config = ConfigResolver().with_env().with_dict({
+            "provider_name": "hetzner",
+            "hetzner": {
+                "auth_token": self.credentials.conf("api_token")
+            },
+
+            "ttl": TTL,
+            "domain": self._get_zone(domain),
+        })
+        return Client(config)
 
     @staticmethod
     def _fqdn_format(name):
         if not name.endswith("."):
             return f"{name}."
         return name
-
-
-class _HetznerClient(dns_common_lexicon.LexiconClient):
-    """
-    Encapsulates all communication with the Hetzner via Lexicon.
-    """
-    def __init__(self, auth_token):
-        super().__init__()
-
-        config = dns_common_lexicon.build_lexicon_config('hetzner', {
-            'ttl': TTL,
-        }, {
-            'auth_token': auth_token,
-        })
-
-        self.provider = hetzner.Provider(config)
